==> dojo-1.9.4.tgz: package/cldr/nls/sl/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Dan v tednu",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d. M. y",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"eraNarrow": [
		"pr. n. št.",
		"po Kr."
	],
	"days-format-short": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"dateFormat-long": "dd. MMMM y",
	"months-format-wide": [
		"januar",
		"februar",
		"marec",
		"april",
		"maj",
		"junij",
		"julij",
		"avgust",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "pop.",
	"dateFormat-full": "EEEE, dd. MMMM y",
	"dateFormatItem-Md": "d. M.",
	"dateFormatItem-yMd": "d. M. y",
	"field-era": "Doba",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"marec",
		"april",
		"maj",
		"junij",
		"julij",
		"avgust",
		"september",
		"oktober",
		"november",
		"december"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. četrtletje",
		"2. četrtletje",
		"3. četrtletje",
		"4. četrtletje"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Leto",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "Ura",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mar.",
		"apr.",
		"maj",
		"jun.",
		"jul.",
		"avg.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "Danes",
	"field-day-relative+1": "Jutri",
	"field-day-relative+2": "Pojutrišnjem",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"avg",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"1. četrtletje",
		"2. četrtletje",
		"3. četrtletje",
		"4. četrtletje"
	],
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"nedelja",
		"ponedeljek",
		"torek",
		"sreda",
		"četrtek",
		"petek",
		"sobota"
	],
	"timeFormat-medium": "HH:mm:ss",
	"dateFormatItem-Hm": "HH:mm",
	"eraAbbr": [
		"pr. n. št.",
		"po Kr."
	],
	"field-minute": "Minuta",
	"field-dayperiod": "Čas dneva",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"tor",
		"sre",
		"čet",
		"pet",
		"sob"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "Včeraj",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "Predvčerajšnjim",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d. MM.",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-day": "Dan",
	"days-format-wide": [
		"nedelja",
		"ponedeljek",
		"torek",
		"sreda",
		"četrtek",
		"petek",
		"sobota"
	],
	"field-zone": "Območje",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-year-relative+-1": "Lani",
	"field-month-relative+-1": "Prejšnji mesec",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"eraNames": [
		"pred našim štetjem",
		"naše štetje"
	],
	"days-format-narrow": [
		"n",
		"p",
		"t",
		"s",
		"č",
		"p",
		"s"
	],
	"field-month": "Mesec",
	"days-standAlone-narrow": [
		"n",
		"p",
		"t",
		"s",
		"č",
		"p",
		"s"
	],
	"dateFormatItem-MMM": "LLL",
	"dayPeriods-format-wide-am": "dop.",
	"dateFormat-short": "d. MM. yy",
	"field-second": "Sekunda",
	"dateFormatItem-yMMMEd": "E, d. MMM y",
	"field-month-relative+0": "Ta mesec",
	"field-month-relative+1": "Naslednji mesec",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Teden",
	"dateFormat-medium": "d. MMM y",
	"field-year-relative+0": "Letos",
	"field-week-relative+-1": "Prejšnji teden",
	"field-year-relative+1": "Naslednje leto",
	"dateFormatItem-mmss": "mm:ss",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-week-relative+0": "Ta teden",
	"field-week-relative+1": "Naslednji teden"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/sl/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-second-relative+0": "zdaj",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Dan v tednu",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d. M. y",
	"field-wed-relative+0": "To sredo",
	"field-wed-relative+1": "Naslednjo sredo",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"eraNarrow": [
		"pr. n. št.",
		"po Kr.",
		"po n. št."
	],
	"field-tue-relative+-1": "Prejšnji torek",
	"days-format-short": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"dateFormat-long": "dd. MMMM y",
	"field-fri-relative+-1": "Prejšnji petek",
	"field-wed-relative+-1": "Prejšnjo sredo",
	"months-format-wide": [
		"januar",
		"februar",
		"marec",
		"april",
		"maj",
		"junij",
		"julij",
		"avgust",
		"september",
		"oktober",
		"november",
		"december"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "pop.",
	"dateFormat-full": "EEEE, dd. MMMM y",
	"field-thu-relative+-1": "Prejšnji četrtek",
	"dateFormatItem-Md": "d. M.",
	"dateFormatItem-yMd": "d. M. y",
	"field-era": "Doba",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"marec",
		"april",
		"maj",
		"junij",
		"julij",
		"avgust",
		"september",
		"oktober",
		"november",
		"december"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. četrtletje",
		"2. četrtletje",
		"3. četrtletje",
		"4. četrtletje"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Leto",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "Ura",
	"months-format-abbr": [
		"jan.",
		"feb.",
		"mar.",
		"apr.",
		"maj",
		"jun.",
		"jul.",
		"avg.",
		"sep.",
		"okt.",
		"nov.",
		"dec."
	],
	"field-sat-relative+0": "To soboto",
	"field-sat-relative+1": "Naslednjo soboto",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-day-relative+0": "danes",
	"field-thu-relative+0": "Ta četrtek",
	"field-day-relative+1": "jutri",
	"field-thu-relative+1": "Naslednji četrtek",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "pojutrišnjem",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"avg",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"1. četrtletje",
		"2. četrtletje",
		"3. četrtletje",
		"4. četrtletje"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"nedelja",
		"ponedeljek",
		"torek",
		"sreda",
		"četrtek",
		"petek",
		"sobota"
	],
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "to nedeljo",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "naslednjo nedeljo",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"eraAbbr": [
		"pr. n. št.",
		"po Kr.",
		"po n. št."
	],
	"field-minute": "Minuta",
	"field-dayperiod": "Čas dneva",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"tor",
		"sre",
		"čet",
		"pet",
		"sob"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "včeraj",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "predvčerajšnjim",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d. MM.",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "Ta petek",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "Naslednji petek",
	"field-day": "Dan",
	"days-format-wide": [
		"nedelja",
		"ponedeljek",
		"torek",
		"sreda",
		"četrtek",
		"petek",
		"sobota"
	],
	"field-zone": "Časovni pas",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-year-relative+-1": "lani",
	"field-month-relative+-1": "prejšnji mesec",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"ned.",
		"pon.",
		"tor.",
		"sre.",
		"čet.",
		"pet.",
		"sob."
	],
	"dateFormatItem-GyM": "M/y G",
	"dateFormatItem-yMMMd": "d. MMM y",
	"eraNames": [
		"pred našim štetjem",
		"naše štetje",
		"po n. št."
	],
	"days-format-narrow": [
		"n",
		"p",
		"t",
		"s",
		"č",
		"p",
		"s"
	],
	"days-standAlone-narrow": [
		"n",
		"p",
		"t",
		"s",
		"č",
		"p",
		"s"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Mesec",
	"field-tue-relative+0": "Ta torek",
	"field-tue-relative+1": "Naslednji torek",
	"dayPeriods-format-wide-am": "dop.",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "ta ponedeljek",
	"field-mon-relative+1": "naslednji ponedeljek",
	"dateFormat-short": "d. MM. yy",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "Prejšnjo soboto",
	"dateFormatItem-yMMMEd": "E, d. MMM y",
	"field-sun-relative+-1": "prejšnjo nedeljo",
	"field-month-relative+0": "ta mesec",
	"field-month-relative+1": "naslednji mesec",
	"dateFormatItem-Ed": "E, d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Teden",
	"dateFormat-medium": "d. MMM y",
	"field-year-relative+0": "letos",
	"field-week-relative+-1": "prejšnji teden",
	"field-year-relative+1": "naslednje leto",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "prejšnji ponedeljek",
	"field-week-relative+0": "ta teden",
	"field-week-relative+1": "naslednji teden"
}
//end v1.x content
);
